@@ -1,4 +1,4 @@
-/* $Id: config.c 21496 2006-05-04 22:12:21Z benny $ */
+/* $Id: config.c 26397 2007-11-28 20:05:51Z benny $ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -318,15 +318,15 @@ config_install_theme (GtkWidget *item,
 
   treeview = GTK_TREE_VIEW (g_object_get_data (G_OBJECT (menu), "tree-view"));
   toplevel = gtk_widget_get_toplevel (GTK_WIDGET (treeview));
-  chooser = xfce_file_chooser_new (_("Choose theme file to install..."),
-                                   GTK_WINDOW (toplevel),
-                                   XFCE_FILE_CHOOSER_ACTION_OPEN,
-                                   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                   GTK_STOCK_OPEN, GTK_RESPONSE_OK,
-                                   NULL);
+  chooser = gtk_file_chooser_dialog_new (_("Choose theme file to install..."),
+                                         GTK_WINDOW (toplevel),
+                                         GTK_FILE_CHOOSER_ACTION_OPEN,
+                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                         GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+                                         NULL);
   if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_OK)
     {
-      file = xfce_file_chooser_get_filename (XFCE_FILE_CHOOSER (chooser));
+      file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
 
       if (!config_do_install_theme (file, treeview))
         {
@@ -705,7 +705,7 @@ config_drag_begin (GtkWidget      *treeview,
   gdk_property_change (context->source_window,
                        gdk_atom_intern ("XdndDirectSave0", FALSE),
                        gdk_atom_intern ("text/plain", FALSE), 8,
-                       GDK_PROP_MODE_REPLACE, filename, strlen (filename));
+                       GDK_PROP_MODE_REPLACE, (const guchar *)filename, strlen (filename));
 
   g_free (filename);
   g_free (name);
@@ -748,7 +748,7 @@ config_drag_data_get (GtkWidget        *treeview,
           prop_text = g_realloc (prop_text, prop_len + 1);
           prop_text[prop_len] = '\0';
 
-          localpath = extract_local_path (prop_text);
+          localpath = extract_local_path ((gchar *)prop_text);
 
           if (localpath != NULL)
             {
@@ -766,7 +766,7 @@ config_drag_data_get (GtkWidget        *treeview,
     }
 
   gtk_selection_data_set (selection_data, gdk_atom_intern ("XA_STRING", FALSE),
-                          8, to_send, 1);
+                          8, (const guchar *)to_send, 1);
 
   g_free (name);
 }
