@@ -1,6 +1,6 @@
-/* $Id: splash.c 20833 2006-04-09 18:08:17Z benny $ */
+/* $Id: splash.c 27021 2008-06-03 17:37:37Z stephan $ */
 /*-
- * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -30,13 +30,15 @@
 #include <string.h>
 #endif
 
+#ifdef XFCE_DISABLE_DEPRECATED
+#undef XFCE_DISABLE_DEPRECATED
+#endif
+
 #include <gdk-pixbuf/gdk-pixdata.h>
 #include <gmodule.h>
 #include <gtk/gtk.h>
 
-#include <libxfce4mcs/mcs-manager.h>
 #include <libxfcegui4/libxfcegui4.h>
-#include <xfce-mcs-manager/manager-plugin.h>
 
 #include <libxfsm/xfsm-util.h>
 #include <libxfsm/xfsm-splash-engine.h>
@@ -333,7 +335,7 @@ splash_selection_changed (GtkTreeSelection *selection)
 
 
 static void
-splash_run (McsPlugin *plugin)
+settings_dialog_new ()
 {
   GtkTreeSelection  *selection;
   GtkTreeViewColumn *column;
@@ -342,7 +344,6 @@ splash_run (McsPlugin *plugin)
   const gchar       *engine;
   GtkTreePath       *path;
   GtkTreeIter        iter;
-  GtkWidget         *header;
   GtkWidget         *hbox;
   GtkWidget         *vbox;
   GtkWidget         *swin;
@@ -358,7 +359,7 @@ splash_run (McsPlugin *plugin)
       return;
     }
 
-  xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
+  xfce_textdomain (GETTEXT_PACKAGE, LOCALEDIR, "UTF-8");
 
   tooltips = gtk_tooltips_new ();
 
@@ -403,25 +404,19 @@ splash_run (McsPlugin *plugin)
   xfce_rc_close (rc);
 
   splash_centered = FALSE;
-  splash_dialog = gtk_dialog_new_with_buttons (_("Splash Screen Settings"),
-                                               NULL,
-                                               GTK_DIALOG_NO_SEPARATOR,
-                                               GTK_STOCK_CLOSE,
-                                               GTK_RESPONSE_CLOSE,
-                                               NULL);
-
-  gtk_window_set_icon (GTK_WINDOW (splash_dialog), plugin->icon);
+  splash_dialog = xfce_titled_dialog_new_with_buttons (_("Splash Screen Settings"),
+                                                       NULL,
+                                                       GTK_DIALOG_NO_SEPARATOR,
+                                                       GTK_STOCK_CLOSE,
+                                                       GTK_RESPONSE_CLOSE,
+                                                       NULL);
+  gtk_window_set_icon_name (GTK_WINDOW (splash_dialog), "xfce4-splash");
 
   g_signal_connect (G_OBJECT (splash_dialog), "response",
                     G_CALLBACK (splash_response), NULL);
   g_signal_connect (G_OBJECT (splash_dialog), "delete-event",
                     G_CALLBACK (splash_response), NULL);
 
-  header = xfce_create_header (plugin->icon, _("Splash Screen Settings"));
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (splash_dialog)->vbox), header,
-                      FALSE, FALSE, 0);
-  gtk_widget_show (header);
-
   hbox = gtk_hbox_new (FALSE, 0);
   gtk_box_pack_start (GTK_BOX (GTK_DIALOG (splash_dialog)->vbox), hbox,
                       TRUE, TRUE, 0);
@@ -569,26 +564,24 @@ splash_run (McsPlugin *plugin)
   gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (splash_treeview), path, NULL,
                                 TRUE, 0.5, 0.0);
   gtk_tree_path_free (path);
-
-  gtk_widget_show (splash_dialog);
 }
 
-
-/*
-   Mcs interface
- */
-McsPluginInitResult
-mcs_plugin_init (McsPlugin *plugin)
+int
+main(int argc, char **argv)
 {
-  xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
+    #ifdef ENABLE_NLS
+    bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+    textdomain (GETTEXT_PACKAGE);
+    #endif
 
-  plugin->plugin_name = g_strdup ("splash");
-  plugin->caption = g_strdup (_("Splash Screen"));
-  plugin->run_dialog = splash_run;
-  plugin->icon = xfce_themed_icon_load ("xfce4-splash", 48);
+    gtk_init(&argc, &argv);
 
-  return MCS_PLUGIN_INIT_OK;
+    settings_dialog_new ();
+    
+
+    gtk_dialog_run(GTK_DIALOG(splash_dialog));
+
+    return 0;
+    
 }
-
-
-MCS_PLUGIN_CHECK_INIT;
