@@ -1,4 +1,4 @@
-/* $Id: main.c 22787 2006-08-15 21:06:25Z benny $ */
+/* $Id: main.c 27686 2008-09-06 12:21:41Z stephan $ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -48,7 +48,6 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 
-#include <libxfce4mcs/mcs-client.h>
 #include <libxfce4util/libxfce4util.h>
 
 #include <libxfsm/xfsm-util.h>
@@ -131,7 +130,6 @@ init_display (GdkDisplay *dpy,
               gboolean disable_tcp)
 {
   const gchar *engine;
-  gint n;
 
   xfce_rc_set_group (rc, "Splash Screen");
   engine = xfce_rc_read_entry (rc, "Engine", NULL);
@@ -143,14 +141,14 @@ init_display (GdkDisplay *dpy,
 
   xfce_rc_set_group (rc, "General");
   sm_init (rc, disable_tcp);
-  
-  /* start a MCS manager process per screen (FIXME: parallel to loading logo) */
-  for (n = 0; n < gdk_display_get_n_screens (dpy); ++n)
-    {
-      mcs_client_check_manager (gdk_x11_display_get_xdisplay (dpy), n,
-                                "xfce-mcs-manager");
-    }
 
+  /* start xfsettingsd */
+  if ( !g_spawn_command_line_async ("xfsettingsd", NULL))
+  {
+    g_warning ("Could not start xfsettingsd");
+  }
+  
+  
   /* gtk resource files may have changed */
   gtk_rc_reparse_all ();
 }
