@@ -1,4 +1,4 @@
-/* $Id: shutdown.c 24158 2006-12-21 21:50:25Z benny $ */
+/* $Id: shutdown.c 27022 2008-06-03 17:45:59Z stephan $ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
@@ -325,7 +325,9 @@ shutdownDialog(gint *shutdownType, gboolean *saveSession)
   gtk_widget_show (vbox2);
   gtk_container_add (GTK_CONTAINER (logout_button), vbox2);
 
-  icon = xfce_themed_icon_load ("xfsm-logout", 32);
+  icon = xfce_themed_icon_load ("system-log-out", 32);
+  if (!icon)
+    icon = xfce_themed_icon_load ("xfsm-logout", 32);
   image = gtk_image_new_from_pixbuf (icon);
   gtk_widget_show (image);
   gtk_box_pack_start (GTK_BOX (vbox2), image, FALSE, FALSE, 0);
@@ -348,7 +350,9 @@ shutdownDialog(gint *shutdownType, gboolean *saveSession)
   gtk_widget_show (vbox2);
   gtk_container_add (GTK_CONTAINER (reboot_button), vbox2);
 
-  icon = xfce_themed_icon_load ("xfsm-reboot", 32);
+  icon = xfce_themed_icon_load ("system-reboot", 32);
+  if (!icon)
+    icon = xfce_themed_icon_load ("xfsm-reboot", 32);
   image = gtk_image_new_from_pixbuf (icon);
   gtk_widget_show (image);
   gtk_box_pack_start (GTK_BOX (vbox2), image, FALSE, FALSE, 0);
@@ -371,7 +375,9 @@ shutdownDialog(gint *shutdownType, gboolean *saveSession)
   gtk_widget_show (vbox2);
   gtk_container_add (GTK_CONTAINER (halt_button), vbox2);
 
-  icon = xfce_themed_icon_load ("xfsm-shutdown", 32);
+  icon = xfce_themed_icon_load ("system-shutdown", 32);
+  if (!icon)
+    icon = xfce_themed_icon_load ("xfsm-shutdown", 32);
   image = gtk_image_new_from_pixbuf (icon);
   gtk_widget_show (image);
   gtk_box_pack_start (GTK_BOX (vbox2), image, FALSE, FALSE, 0);
@@ -479,7 +485,7 @@ shutdownDialog(gint *shutdownType, gboolean *saveSession)
           if (!xfsm_shutdown_helper_send_password (shutdown_helper, pw))
             {
               gtk_label_set_text (GTK_LABEL (label),
-                                  _("<b>An error occured</b>"));
+                                  _("<b>An error occurred</b>"));
               gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
               gtk_container_remove (GTK_CONTAINER (
